@@ -28,7 +28,7 @@
 #'   class depends on the input object. \code{plot}, \code{summary} methods are
 #'   available to display the results of computations, and additional methods
 #'   may be available depending on the input object (e.g. see
-#'   \link{patchdistr_sews_plot}). 
+#'   \code{\link{patchdistr_sews_plot}}). 
 #' 
 #' @details 
 #' 
@@ -37,25 +37,45 @@
 #'   in the absence of the biological process of interest. 
 #' 
 #' For a given indicator, a null distribution is obtained by producing a set 
-#'   of 'null' matrices on which indicator values are recomputed. This produces 
-#'   a null distribution of \code{nulln} values against which the observed
-#'   value is tested. 
+#'   of 'null' matrices, from which indicator values are recomputed. This
+#'   produces a null distribution of \code{nulln} indicator values against
+#'   which the observed value is tested. 
 #' 
 #' Several methods are available to produce the set of null matrices. If 
-#'   \code{null_method} is set ot "perm", the original matrix is reshuffled 
-#'   to obtain a null matrix. If the method is "binom", the mean cover of a 
-#'   matrix \deqn{mu} is computed, then the matrix is filled randomly with 
-#'   TRUE values (with probability \deqn{mu}) and FALSE (with probability 
-#'   \deqn{1 - mu}). This method only works with logical matrices (with 
-#'   TRUE/FALSE values). 
+#'   \code{null_method} is set to "perm", the original matrix is reshuffled 
+#'   to obtain a null matrix. If \code{null_method} is set to "intercept", then 
+#'   a generalized linear model of the form `y ~ 1` (where y represents the 
+#'   values of the matrix) is fitted, then values are drawn from this model. If 
+#'   \code{null_method} is set to "smooth", then a smooth surface is fitted
+#'   based on a generalized additive model (using \code{\link[=mgcv]{gam}}) to
+#'   the matrix, then values are drawn from this model. When using the
+#'   "intercept" or "smooth" null models, it is important to make sure the
+#'   model 'family' corresponds to the type of values present in the matrix. By
+#'   default, if a matrix contains TRUE/FALSE values, a `binomial()` family is
+#'   used, otherwise a `gaussian()` family is used. More information about null
+#'   models is available in the \href{https://alex.lecairn.org/spatialwarnings-faq.html#Using_advanced_null_models}{spatialwarnings FAQ}. 
 #' 
-#' \code{null_method} can be set to 'smooth'. In that case, an isotropic spline 
-#'   will be fitted to the matrix (using \link[mgcv]{gam}), and values will 
-#'   be 
+#' Please note that specific null methods may exists for some indicators, such as
+#' \code{\link[=flowlength_sews]{flowlength}}. These are often based on 
+#' analytical approximation and allow faster computations. 
+#' 
+#' The list \code{null_control} can be used to adjust the computation of 
+#'   null matrices. It can have the following components: 
+#'   \itemize{ 
+#'     \item `family` The family used in the model used to produce the null 
+#'       matrices. Typically, it is one of \code{\link[=stats]{binomial}()}, 
+#'       \code{\link[=stats]{binomial}()}, etc. 
+#' 
+#'     \item `qinf` The lower quantile to compute from the null distribution 
+#'       and display in summaries/plots. A numeric value between 0 and 1.
+#' 
+#'     \item `qsup` The upper quantile to compute from the null distribution 
+#'       and display in summaries/plots. A numeric value between 0 and 1.
+#'   }
 #' 
 #' @seealso \code{\link{generic_sews}}, \code{\link{spectral_sews}}, 
 #'   \code{\link{kbdm_sews}},
-#'   \code{\link{compute_indicator}}
+#'   \code{\link{compute_indicator}}, \code{\link{flowlength_sews}}
 #' 
 #' @references 
 #' 
@@ -70,9 +90,9 @@ indictest <- function(x,
                       null_control = NULL, 
                       ...) { 
   # If indictest has already run on the object, return itself
-  if ( any(grepl("_sews_test_", class(x))) ) { 
-    return(x)
-  }
+#   if ( any(grepl("_sews_test_", class(x))) ) { 
+#     return(x)
+#   }
   
   UseMethod('indictest')
 }
